@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- encoding: utf8 -*-
 
 """Support functions for config (.INI) file reading
@@ -24,19 +24,28 @@ Copyright/licensing:
     limitations under the License.
 """
 
+from configparser import ConfigParser, NoOptionError
+from typing import Any, Iterable, List
 
 # =============================================================================
 # Config
 # =============================================================================
 
 
-def get_config_string_option(parser, section, option, default=None):
+def get_config_string_option(parser: ConfigParser,
+                             section: str,
+                             option: str,
+                             default: str = None) -> str:
     if not parser.has_section(section):
         raise ValueError("config missing section: " + section)
     return parser.get(section, option, fallback=default)
 
 
-def read_config_string_options(obj, parser, section, options, default=None):
+def read_config_string_options(obj: Any,
+                               parser: ConfigParser,
+                               section: str,
+                               options: Iterable[str],
+                               default: str = None) -> None:
     # enforce_str removed; ConfigParser always returns strings unless asked
     # specifically
     for o in options:
@@ -44,7 +53,10 @@ def read_config_string_options(obj, parser, section, options, default=None):
                                                  default=default))
 
 
-def get_config_multiline_option(parser, section, option, default=None):
+def get_config_multiline_option(parser: ConfigParser,
+                                section: str,
+                                option: str,
+                                default: List[str] = None) -> List[str]:
     default = default or []
     if not parser.has_section(section):
         raise ValueError("config missing section: " + section)
@@ -52,16 +64,22 @@ def get_config_multiline_option(parser, section, option, default=None):
         multiline = parser.get(section, option)
         values = [x.strip() for x in multiline.splitlines() if x.strip()]
         return values
-    except configparser.NoOptionError:
+    except NoOptionError:
         return default
 
 
-def read_config_multiline_options(obj, parser, section, options):
+def read_config_multiline_options(obj: Any,
+                                  parser: ConfigParser,
+                                  section: str,
+                                  options: Iterable[str]) -> None:
     for o in options:
         setattr(obj, o, get_config_multiline_option(parser, section, o))
 
 
-def get_config_bool_option(parser, section, option, default=None):
+def get_config_bool_option(parser: ConfigParser,
+                           section: str,
+                           option: str,
+                           default: bool = None) -> bool:
     if not parser.has_section(section):
         raise ValueError("config missing section: " + section)
     return parser.getboolean(section, option, fallback=default)
