@@ -4,7 +4,7 @@
 # See LICENSE for details.
 
 
-VERSION = '0.2.7'
+VERSION = '0.2.8'
 # Use semantic versioning: http://semver.org/
 
 RECENT_VERSION_HISTORY = """
@@ -12,5 +12,8 @@ RECENT_VERSION_HISTORY = """
 - 0.2.7, 2017-04-28
   Fixed bug in rnc_extract_text that was using get_file_contents() as a
   converter when it wasn't accepting generic **kwargs; now it is.
+  
+- 0.2.8, 2017-04-28
+  Fixed DOCX table processing bug, in docx_process_table().
 
-"""
\ No newline at end of file
+"""
